# Licensed under a 3-clause BSD style license - see LICENSE.rst
"""
==========
eHST Init
==========

European Space Astronomy Centre (ESAC)
European Space Agency (ESA)

"""
